@@ -1,5 +1,4 @@
 import os
-from datetime import datetime
 
 import pytest
 import requests
@@ -8,6 +7,25 @@ import responses
 from hyp3lib import fetch
 
 
+def test_write_credentials_to_netrc_file(tmp_path):
+    os.environ['HOME'] = str(tmp_path)
+    output_file = tmp_path / '.netrc'
+
+    fetch.write_credentials_to_netrc_file('foo', 'bar')
+    assert output_file.is_file()
+    with open(output_file, 'r') as f:
+        assert f.read() == 'machine urs.earthdata.nasa.gov login foo password bar\n'
+
+    fetch.write_credentials_to_netrc_file('already_there', 'this call should do nothing')
+    with open(output_file, 'r') as f:
+        assert f.read() == 'machine urs.earthdata.nasa.gov login foo password bar\n'
+
+    fetch.write_credentials_to_netrc_file('append', 'this', domain='domain', append=True)
+    with open(output_file, 'r') as f:
+        assert f.read() == 'machine urs.earthdata.nasa.gov login foo password bar\n' \
+                           'machine domain login append password this\n'
+
+
 @responses.activate
 def test_download_file(safe_data, tmp_path):
     with open(os.path.join(safe_data, 'granule_name.txt')) as f:
@@ -20,7 +38,7 @@ def test_download_file(safe_data, tmp_path):
 
     download_path = fetch.download_file('http://hyp3.asf.alaska.edu/foobar.txt', directory=tmp_path)
 
-    assert download_path == str(tmp_path / 'foobar.txt')
+    assert download_path == os.path.join(tmp_path, 'foobar.txt')
     assert os.path.exists(download_path)
     with open(download_path) as f:
         assert f.read() == text
@@ -38,24 +56,12 @@ def test_download_file_in_chunks(safe_data, tmp_path):
 
     download_path = fetch.download_file('http://hyp3.asf.alaska.edu/foobar.txt', directory=tmp_path, chunk_size=1)
 
-    assert download_path == str(tmp_path / 'foobar.txt')
+    assert download_path == os.path.join(tmp_path, 'foobar.txt')
     assert os.path.exists(download_path)
     with open(download_path) as f:
         assert f.read() == text
 
 
-def test_download_file_retries():
-    backoff_factor = 1
-    total_retries = 2
-    expected_time = backoff_factor * (2 ** (total_retries - 1))
-
-    before = datetime.now()
-    with pytest.raises(requests.exceptions.RetryError):
-        _ = fetch.download_file('http://httpstat.us/500', backoff_factor=backoff_factor, retries=total_retries)
-    after = datetime.now()
-    assert (after - before).seconds >= expected_time
-
-
 def test_download_file_none():
     with pytest.raises(requests.exceptions.InvalidURL):
         _ = fetch.download_file(url=None)
